# create tables with your own style

```jsx
import injectSheet from 'lib/sheet';
import DataTable from './data-table/DataTable';

const sheet = {
  // default classNames
  DataTable: {
    // root
  },
  tr: {},
  trEven: {},
  trOdd: {},
  th: {},
  td: {},
  tdEmpty: {},
  trh: {},
  // your own classNames
  thumb: {},
};

export default injectSheet(sheet)(DataTable);
```

# define table columns

```jsx
import React from 'react';
import I from 'immutable';
import { columnsSelector } from 'react-immutable-jss-data-table';

export const columns = {
  // use rowIndex:
  cell0: {
    getValue: ({ rowIndex }) => `# ${rowIndex}`,
  },
  // add extra class, it will be searched in classes prop or cellClasses prop or used as is
  cell1: {
    className: 'my-own-class-name',
  },
  cell2: {
    // you can cpecify how to extract data from entries (rowData.getIn(fieldPath))
    fieldPath: ['article', 'title'],
    // then you can change the value
    getValue: ({ value }) => `Title: ${value}`,
  },
  cell3: {
    // how to extract data from rowData,
    fieldPath: ['article', 'title'],
    // then you can change the value
    getValue: ({ value, rowData }) => `Title: ${value}`,
    // you can render cell using your own component
    render: ({ value, rowData }) => <li children={'changed value: ' + value} />
  },
  // if you whant to show table th titles, please use 'title' prop
  cell4: {
    fieldPath: ['someField'],
    // column title (th)
    title: 'colum title',
    // you can change default title, f.e. add items amout
    getValueTh: ({ value, items }) => `${value} (${itmes.size})`,
    // render th using your own component
    renderTh: hoToRenderTh,
  },
  // you can change cell inner content markup using getValue:
  link: {
    fieldPath: ['article', 'url'],
    getValue: ({ value }) => <Link to={value} />,
  },
  // use DataTable props (<DataTable user={user}/>)
  user: {
    fieldPath: ['userId'],
    getValue: ({ classes, rowData, value, rowIndex, user }) =>
      <div
        className={classes.thumb}
        children={users.getFullNameById(value)}
      />,
  },
  // change cell markup fully
  clickMe: {
    render: ({ className, classes, rowData, value, rowIndex, props }) =>
      <div
        className={className}
        children={value}
        onClick={() => props.toggleEditRow(rowIndex)}
      />
  },

  select: null,
};
columns.select = columnsSelector(columns);

export default columns;
```

#### available options for columns:

 * `name` - column name, used to identify it f.e. when orderBy used
 * `fieldPath` - array used for Immutable.getIn method to extract value from rowData
 * `className` - custom className, used as additional className for cell
 * `getValue` - func, returns node or string or number, that will be placed as child in cell node
 * `getValueTh` - func, returns node or string or number, that will be placed as child in th node
 * `render` - func returns node, replaces cell root node
 * `titleId` - intl translation id
 * `titleDefaultMessage` - message that should be shown if no translation found
 * `orderBy` - column name or one of [null, undefined, false, etc. ]

`fieldPath` if empty `[name]` will be used to extract data

`getValue(value, rowData, rowIndex, props, classes)` used to extract data from rowData and props or change cell content markup.<br />
`value` got using `fieldPath` or `[name]` from `rowData.getIn(path)`


`render(value, rowData, rowIndex, props, classes)` used to fully change cell markup, have same arguments as `getValue`, but `value` in this
can have markup or data from `getValue` if specified


# use DataTable in your Components

```jsx
import DataTable from './my/styledTable';
import tableColumns from './my/table/columns.jsx'

const columns = tableColumns.select('title', 'link', 'user', 'clickMe');

class MyPage extends React.PureComponent {

  render() {
    const { classes, list } = this.props;
    return (
      <div
        className={classes.container}
      >
        <DataTable
          columns={columns}
          items={list}
        />
      </div>
    );
  }
}
```
